Interface: RadarControllerDatasetOptions | Chart.js
Description: Open source HTML5 Charts for your website

# # Interface: RadarControllerDatasetOptions

## # Hierarchy

- `ControllerDatasetOptions`

- `ScriptableAndArrayOptions`<`PointOptions` & `PointHoverOptions` & `PointPrefixedOptions` & `PointPrefixedHoverOptions`, `ScriptableContext`<`"radar"`>>

- `ScriptableAndArrayOptions`<`LineOptions` & `LineHoverOptions`, `ScriptableContext`<`"radar"`>>

- `AnimationOptions`<`"radar"`>

  ↳ `RadarControllerDatasetOptions`

## # Properties

### # animation

• animation: `false` | `AnimationSpec`<`"radar"`> & { `onComplete?`: (`event`: `AnimationEvent`) => `void` ; `onProgress?`: (`event`: `AnimationEvent`) => `void` }

#### # Inherited from

AnimationOptions.animation

#### # Defined in

index.esm.d.ts:1640
(opens new window)

### # animations

• animations: `AnimationsSpec`<`"radar"`>

#### # Inherited from

AnimationOptions.animations

#### # Defined in

index.esm.d.ts:1650
(opens new window)

### # backgroundColor

• backgroundColor: `ScriptableAndArray`<`Color`, `ScriptableContext`<`"radar"`>>

#### # Inherited from

ScriptableAndArrayOptions.backgroundColor

#### # Defined in

index.esm.d.ts:1696
(opens new window)

### # borderCapStyle

• borderCapStyle: `ScriptableAndArray`<`CanvasLineCap`, `ScriptableContext`<`"radar"`>>

Line cap style. See MDN.

`default` 'butt'

#### # Inherited from

ScriptableAndArrayOptions.borderCapStyle

#### # Defined in

index.esm.d.ts:1779
(opens new window)

### # borderColor

• borderColor: `ScriptableAndArray`<`Color`, `ScriptableContext`<`"radar"`>>

#### # Inherited from

ScriptableAndArrayOptions.borderColor

#### # Defined in

index.esm.d.ts:1695
(opens new window)

### # borderDash

• borderDash: `ScriptableAndArray`<`number`[], `ScriptableContext`<`"radar"`>>

Line dash. See MDN.

`default` []

#### # Inherited from

ScriptableAndArrayOptions.borderDash

#### # Defined in

index.esm.d.ts:1784
(opens new window)

### # borderDashOffset

• borderDashOffset: `ScriptableAndArray`<`number`, `ScriptableContext`<`"radar"`>>

Line dash offset. See MDN.

`default` 0.0

#### # Inherited from

ScriptableAndArrayOptions.borderDashOffset

#### # Defined in

index.esm.d.ts:1789
(opens new window)

### # borderJoinStyle

• borderJoinStyle: `ScriptableAndArray`<`CanvasLineJoin`, `ScriptableContext`<`"radar"`>>

Line join style. See MDN.

`default` 'miter'

#### # Inherited from

ScriptableAndArrayOptions.borderJoinStyle

#### # Defined in

index.esm.d.ts:1794
(opens new window)

### # borderWidth

• borderWidth: `ScriptableAndArray`<`number`, `ScriptableContext`<`"radar"`>>

#### # Inherited from

ScriptableAndArrayOptions.borderWidth

#### # Defined in

index.esm.d.ts:1694
(opens new window)

### # capBezierPoints

• capBezierPoints: `ScriptableAndArray`<`boolean`, `ScriptableContext`<`"radar"`>>

true to keep Bézier control inside the chart, false for no restriction.

`default` true

#### # Inherited from

ScriptableAndArrayOptions.capBezierPoints

#### # Defined in

index.esm.d.ts:1799
(opens new window)

### # clip

• clip: `number` | `false` | `ChartArea`

How to clip relative to chartArea. Positive value allows overflow, negative value clips that many pixels inside chartArea. 0 = clip at chartArea. Clipping can also be configured per side: clip: {left: 5, top: false, right: -2, bottom: 0}

#### # Inherited from

ControllerDatasetOptions.clip

#### # Defined in

index.esm.d.ts:70
(opens new window)

### # cubicInterpolationMode

• cubicInterpolationMode: `ScriptableAndArray`<`"default"` | `"monotone"`, `ScriptableContext`<`"radar"`>>

Interpolation mode to apply.

`default` 'default'

#### # Inherited from

ScriptableAndArrayOptions.cubicInterpolationMode

#### # Defined in

index.esm.d.ts:1804
(opens new window)

### # drawActiveElementsOnTop

• drawActiveElementsOnTop: `ScriptableAndArray`<`boolean`, `ScriptableContext`<`"radar"`>>

Draw the active elements over the other elements of the dataset,

`default` true

#### # Inherited from

ScriptableAndArrayOptions.drawActiveElementsOnTop

#### # Defined in

index.esm.d.ts:1904
(opens new window)

### # fill

• fill: `ScriptableAndArray`<`FillTarget` | `ComplexFillTarget`, `ScriptableContext`<`"radar"`>>

Both line and radar charts support a fill option on the dataset object which can be used to create area between two datasets or a dataset and a boundary, i.e. the scale origin, start or end

#### # Inherited from

ScriptableAndArrayOptions.fill

#### # Defined in

index.esm.d.ts:1818
(opens new window)

### # hidden

• hidden: `boolean`

Configures the visibility state of the dataset. Set it to true, to hide the dataset from the chart.

`default` false

#### # Inherited from

ControllerDatasetOptions.hidden

#### # Defined in

index.esm.d.ts:88
(opens new window)

### # hitRadius

• hitRadius: `ScriptableAndArray`<`number`, `ScriptableContext`<`"radar"`>>

Extra radius added to point radius for hit detection.

`default` 1

#### # Inherited from

ScriptableAndArrayOptions.hitRadius

#### # Defined in

index.esm.d.ts:1889
(opens new window)

### # hoverBackgroundColor

• hoverBackgroundColor: `ScriptableAndArray`<`Color`, `ScriptableContext`<`"radar"`>>

#### # Inherited from

ScriptableAndArrayOptions.hoverBackgroundColor

#### # Defined in

index.esm.d.ts:1702
(opens new window)

### # hoverBorderCapStyle

• hoverBorderCapStyle: `ScriptableAndArray`<`CanvasLineCap`, `ScriptableContext`<`"radar"`>>

#### # Inherited from

ScriptableAndArrayOptions.hoverBorderCapStyle

#### # Defined in

index.esm.d.ts:1836
(opens new window)

### # hoverBorderColor

• hoverBorderColor: `ScriptableAndArray`<`Color`, `ScriptableContext`<`"radar"`>>

#### # Inherited from

ScriptableAndArrayOptions.hoverBorderColor

#### # Defined in

index.esm.d.ts:1701
(opens new window)

### # hoverBorderDash

• hoverBorderDash: `ScriptableAndArray`<`number`[], `ScriptableContext`<`"radar"`>>

#### # Inherited from

ScriptableAndArrayOptions.hoverBorderDash

#### # Defined in

index.esm.d.ts:1837
(opens new window)

### # hoverBorderDashOffset

• hoverBorderDashOffset: `ScriptableAndArray`<`number`, `ScriptableContext`<`"radar"`>>

#### # Inherited from

ScriptableAndArrayOptions.hoverBorderDashOffset

#### # Defined in

index.esm.d.ts:1838
(opens new window)

### # hoverBorderJoinStyle

• hoverBorderJoinStyle: `ScriptableAndArray`<`CanvasLineJoin`, `ScriptableContext`<`"radar"`>>

#### # Inherited from

ScriptableAndArrayOptions.hoverBorderJoinStyle

#### # Defined in

index.esm.d.ts:1839
(opens new window)

### # hoverBorderWidth

• hoverBorderWidth: `ScriptableAndArray`<`number`, `ScriptableContext`<`"radar"`>>

#### # Inherited from

ScriptableAndArrayOptions.hoverBorderWidth

#### # Defined in

index.esm.d.ts:1700
(opens new window)

### # hoverRadius

• hoverRadius: `ScriptableAndArray`<`number`, `ScriptableContext`<`"radar"`>>

Point radius when hovered.

`default` 4

#### # Inherited from

ScriptableAndArrayOptions.hoverRadius

#### # Defined in

index.esm.d.ts:1912
(opens new window)

### # indexAxis

• indexAxis: `"x"` | `"y"`

The base axis of the chart. 'x' for vertical charts and 'y' for horizontal charts.

`default` 'x'

#### # Inherited from

ControllerDatasetOptions.indexAxis

#### # Defined in

index.esm.d.ts:66
(opens new window)

### # label

• label: `string`

The label for the dataset which appears in the legend and tooltips.

#### # Inherited from

ControllerDatasetOptions.label

#### # Defined in

index.esm.d.ts:74
(opens new window)

### # normalized

• normalized: `boolean`

Chart.js is fastest if you provide data with indices that are unique, sorted, and consistent across datasets and provide the normalized: true option to let Chart.js know that you have done so.

#### # Inherited from

ControllerDatasetOptions.normalized

#### # Defined in

index.esm.d.ts:58
(opens new window)

### # order

• order: `number`

The drawing order of dataset. Also affects order for stacking, tooltip and legend.

#### # Inherited from

ControllerDatasetOptions.order

#### # Defined in

index.esm.d.ts:78
(opens new window)

### # parsing

• parsing: `false` | { [key: string]: `string`; }

How to parse the dataset. The parsing can be disabled by specifying parsing: false at chart options or dataset. If parsing is disabled, data must be sorted and in the formats the associated chart type and scales use internally.

#### # Inherited from

ControllerDatasetOptions.parsing

#### # Defined in

index.esm.d.ts:49
(opens new window)

### # pointBackgroundColor

• pointBackgroundColor: `ScriptableAndArray`<`Color`, `ScriptableContext`<`"radar"`>>

The fill color for points.

#### # Inherited from

ScriptableAndArrayOptions.pointBackgroundColor

#### # Defined in

index.esm.d.ts:1919
(opens new window)

### # pointBorderColor

• pointBorderColor: `ScriptableAndArray`<`Color`, `ScriptableContext`<`"radar"`>>

The border color for points.

#### # Inherited from

ScriptableAndArrayOptions.pointBorderColor

#### # Defined in

index.esm.d.ts:1923
(opens new window)

### # pointBorderWidth

• pointBorderWidth: `ScriptableAndArray`<`number`, `ScriptableContext`<`"radar"`>>

The width of the point border in pixels.

#### # Inherited from

ScriptableAndArrayOptions.pointBorderWidth

#### # Defined in

index.esm.d.ts:1927
(opens new window)

### # pointHitRadius

• pointHitRadius: `ScriptableAndArray`<`number`, `ScriptableContext`<`"radar"`>>

The pixel size of the non-displayed point that reacts to mouse events.

#### # Inherited from

ScriptableAndArrayOptions.pointHitRadius

#### # Defined in

index.esm.d.ts:1931
(opens new window)

### # pointHoverBackgroundColor

• pointHoverBackgroundColor: `ScriptableAndArray`<`Color`, `ScriptableContext`<`"radar"`>>

Point background color when hovered.

#### # Inherited from

ScriptableAndArrayOptions.pointHoverBackgroundColor

#### # Defined in

index.esm.d.ts:1950
(opens new window)

### # pointHoverBorderColor

• pointHoverBorderColor: `ScriptableAndArray`<`Color`, `ScriptableContext`<`"radar"`>>

Point border color when hovered.

#### # Inherited from

ScriptableAndArrayOptions.pointHoverBorderColor

#### # Defined in

index.esm.d.ts:1954
(opens new window)

### # pointHoverBorderWidth

• pointHoverBorderWidth: `ScriptableAndArray`<`number`, `ScriptableContext`<`"radar"`>>

Border width of point when hovered.

#### # Inherited from

ScriptableAndArrayOptions.pointHoverBorderWidth

#### # Defined in

index.esm.d.ts:1958
(opens new window)

### # pointHoverRadius

• pointHoverRadius: `ScriptableAndArray`<`number`, `ScriptableContext`<`"radar"`>>

The radius of the point when hovered.

#### # Inherited from

ScriptableAndArrayOptions.pointHoverRadius

#### # Defined in

index.esm.d.ts:1962
(opens new window)

### # pointRadius

• pointRadius: `ScriptableAndArray`<`number`, `ScriptableContext`<`"radar"`>>

The radius of the point shape. If set to 0, the point is not rendered.

#### # Inherited from

ScriptableAndArrayOptions.pointRadius

#### # Defined in

index.esm.d.ts:1935
(opens new window)

### # pointRotation

• pointRotation: `ScriptableAndArray`<`number`, `ScriptableContext`<`"radar"`>>

The rotation of the point in degrees.

#### # Inherited from

ScriptableAndArrayOptions.pointRotation

#### # Defined in

index.esm.d.ts:1939
(opens new window)

### # pointStyle

• pointStyle: `ScriptableAndArray`<`PointStyle`, `ScriptableContext`<`"radar"`>>

Point style

`default` 'circle;

#### # Inherited from

ScriptableAndArrayOptions.pointStyle

#### # Defined in

index.esm.d.ts:1894
(opens new window)

### # radius

• radius: `ScriptableAndArray`<`number`, `ScriptableContext`<`"radar"`>>

Point radius

`default` 3

#### # Inherited from

ScriptableAndArrayOptions.radius

#### # Defined in

index.esm.d.ts:1884
(opens new window)

### # rotation

• rotation: `ScriptableAndArray`<`number`, `ScriptableContext`<`"radar"`>>

Point rotation (in degrees).

`default` 0

#### # Inherited from

ScriptableAndArrayOptions.rotation

#### # Defined in

index.esm.d.ts:1899
(opens new window)

### # segment

• segment: `ScriptableAndArray`<{ `backgroundColor`: `Scriptable`<`Color`, `ScriptableLineSegmentContext`> ; `borderCapStyle`: `Scriptable`<`CanvasLineCap`, `ScriptableLineSegmentContext`> ; `borderColor`: `Scriptable`<`Color`, `ScriptableLineSegmentContext`> ; `borderDash`: `Scriptable`<`number`[], `ScriptableLineSegmentContext`> ; `borderDashOffset`: `Scriptable`<`number`, `ScriptableLineSegmentContext`> ; `borderJoinStyle`: `Scriptable`<`CanvasLineJoin`, `ScriptableLineSegmentContext`> ; `borderWidth`: `Scriptable`<`number`, `ScriptableLineSegmentContext`> }, `ScriptableContext`<`"radar"`>>

#### # Inherited from

ScriptableAndArrayOptions.segment

#### # Defined in

index.esm.d.ts:1824
(opens new window)

### # showLine

• showLine: `boolean`

If false, the line is not drawn for this dataset.

#### # Defined in

index.esm.d.ts:415
(opens new window)

### # spanGaps

• spanGaps: `number` | `boolean`

If true, lines will be drawn between points with no or null data. If false, points with NaN data will create a break in the line. Can also be a number specifying the maximum gap length to span. The unit of the value depends on the scale used.

#### # Overrides

ScriptableAndArrayOptions.spanGaps

#### # Defined in

index.esm.d.ts:410
(opens new window)

### # stack

• stack: `string`

The ID of the group to which this dataset belongs to (when stacked, each group will be a separate stack).

#### # Inherited from

ControllerDatasetOptions.stack

#### # Defined in

index.esm.d.ts:83
(opens new window)

### # stepped

• stepped: `ScriptableAndArray`<`boolean` | `"middle"` | `"before"` | `"after"`, `ScriptableContext`<`"radar"`>>

true to show the line as a stepped line (tension will be ignored).

`default` false

#### # Inherited from

ScriptableAndArrayOptions.stepped

#### # Defined in

index.esm.d.ts:1814
(opens new window)

### # tension

• tension: `ScriptableAndArray`<`number`, `ScriptableContext`<`"radar"`>>

Bézier curve tension (0 for no Bézier curves).

`default` 0

#### # Inherited from

ScriptableAndArrayOptions.tension

#### # Defined in

index.esm.d.ts:1809
(opens new window)

### # transitions

• transitions: `TransitionsSpec`<`"radar"`>

#### # Inherited from

AnimationOptions.transitions

#### # Defined in

index.esm.d.ts:1651
(opens new window)

### # xAxisID

• xAxisID: `string`

The ID of the x axis to plot this dataset on.

#### # Defined in

index.esm.d.ts:401
(opens new window)

### # yAxisID

• yAxisID: `string`

The ID of the y axis to plot this dataset on.

#### # Defined in

index.esm.d.ts:405
(opens new window)